"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Redis = void 0;
const redis_tag_cache_1 = __importDefault(require("redis-tag-cache"));
const Errors_1 = require("../Errors");
const Lambda_1 = require("../Lambda");
const autobind_decorator_1 = require("autobind-decorator");
const MAX_AGE_IN_SECS = 6 * 60 * 60;
let redisTagCache = null;
function getRedisTagCache() {
    const port = Lambda_1.getEnvConfig('REDIS_PORT');
    const host = Lambda_1.getEnvConfig('REDIS_ENDPOINT');
    if (!redisTagCache && port && host) {
        redisTagCache = new redis_tag_cache_1.default({
            defaultTimeout: MAX_AGE_IN_SECS,
            redis: {
                port: parseInt(port),
                host: host,
            },
        });
    }
    return redisTagCache;
}
// TODO implement promise timeout
class Redis {
    constructor() {
        this.redis = null;
    }
    getOrCreateConnection() {
        if (!this.redis) {
            this.redis = getRedisTagCache();
            if (!this.redis)
                throw new Errors_1.InternalServerError('No redis cluster found');
        }
        return this.redis;
    }
    async get(key) {
        const connection = this.getOrCreateConnection();
        return await connection.get(key);
    }
    async set(key, data, tags, options) {
        const connection = this.getOrCreateConnection();
        await connection.set(key, data, tags, options);
    }
    async invalidate(...tags) {
        const connection = this.getOrCreateConnection();
        await connection.invalidate(...tags);
    }
}
__decorate([
    autobind_decorator_1.boundMethod
], Redis.prototype, "getOrCreateConnection", null);
__decorate([
    autobind_decorator_1.boundMethod
], Redis.prototype, "get", null);
__decorate([
    autobind_decorator_1.boundMethod
], Redis.prototype, "set", null);
__decorate([
    autobind_decorator_1.boundMethod
], Redis.prototype, "invalidate", null);
exports.Redis = Redis;
